/********************************************************************
  BasicDSP
  Copyright 2006-2007 
  Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org
  Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl
  License: GPLv2
********************************************************************/

#include "graphframe.h"
#include <vector>

BEGIN_EVENT_TABLE(MyGraphFrame, wxFrame)
	EVT_CLOSE(MyGraphFrame::OnClose)
  EVT_BUTTON(1,MyGraphFrame::OnCopyToClipboard)
END_EVENT_TABLE()

#ifdef WIN32
#define ENABLE_CLIPBOARD
#include <wx/clipbrd.h>
#endif

MyGraphFrame::MyGraphFrame(
   wxFrame *parent, 
   wxString title, 
   wxArrayString checkboxnames, 
   const wxString &xf, 
   const wxString &xfk,
   GraphFrameCloseReceiver *_closereceiver)
   : wxFrame(parent, -1, title),
   myparent(parent),
   closereceiver(_closereceiver)
{
   wxPanel *panel = new wxPanel(this);

   wxBoxSizer *topsizer = new wxBoxSizer(wxVERTICAL);

   specplot = new wxSpectrumplot(panel, -1, _T("test"), xf, xfk, wxDefaultPosition, wxDefaultSize);
   topsizer->Add(specplot, 1, wxEXPAND);

   wxBoxSizer *sizer;
   sizer = new wxBoxSizer(wxHORIZONTAL);
#ifdef ENABLE_CLIPBOARD
   toclipboard = new wxButton(panel, 1, _T("Copy to\nclipboard"));
   sizer->Add(toclipboard, 0, wxEXPAND | wxALL, 4);
#endif
      for (size_t i=0;i<checkboxnames.size();i++) 
      {
         wxCheckBox *cb = new wxCheckBox(panel, -1, checkboxnames[i]);
         sizer->Add(cb, 1, wxEXPAND | wxALL, 4);
         checkboxes.push_back(cb);
      }
      varname_l = new wxTextCtrl(panel, -1, _T("outl"), wxDefaultPosition, wxDefaultSize, wxTE_DONTWRAP | wxTE_RICH | wxTE_PROCESS_ENTER);
      varname_l -> SetBackgroundColour(wxColour(255,255,0));
      sizer->Add(varname_l, 1, wxEXPAND | wxALL, 4);
      varname_r = new wxTextCtrl(panel, -1, _T("outr"), wxDefaultPosition, wxDefaultSize, wxTE_DONTWRAP | wxTE_RICH | wxTE_PROCESS_ENTER);
      varname_r -> SetBackgroundColour(wxColour(0,255,255));
      sizer->Add(varname_r, 1, wxEXPAND | wxALL, 4);
   topsizer->Add(sizer,0,wxEXPAND);
   panel->SetSizer(topsizer);

   Show(TRUE);
};

MyGraphFrame::~MyGraphFrame()
{
}

void MyGraphFrame::SetMinMax(float dbmi, float dbma, float fmi, float fma, float xz)
{
	specplot->SetMinMax(dbmi, dbma, fmi, fma, xz);
}

void MyGraphFrame::SetLevel(float *l , float *r)
{
	specplot->SetLevel(l,r);
}

void MyGraphFrame::OnClose(wxCloseEvent& event)
{
   if (closereceiver)
     closereceiver->GFrameCloseNotify(this);  // send a close notification.

   Destroy();
}

void MyGraphFrame::SetTooltip(int boxnumber, const wxString &tiptext)
{
  if ((boxnumber < 0) || (boxnumber >= checkboxes.size())) return;  // out of range!
  checkboxes[boxnumber]->SetToolTip(tiptext);
}

void MyGraphFrame::OnCopyToClipboard(wxCommandEvent& event)
{
#ifdef ENABLE_CLIPBOARD
#if 0
  wxString mytext;
  // write all the data to mytext
  const float *yellow = specplot->GetYellowDataPtr();
  const float *cyan   = specplot->GetCyanDataPtr();
  wxString newline;
  for(unsigned int i=0; i<1024; i++)
  {
    newline.Printf(_T("%d %f %f"), i, yellow[i], cyan[i]);
    newline.Append(_T(" \r\n"));
    mytext.Append(newline);
  }
#endif
  if (wxTheClipboard->Open())
  {
    // This data objects are held by the clipboard, 
    // so do not delete them in the app.
    //wxTheClipboard->SetData( new wxTextDataObject(mytext));
    wxTheClipboard->SetData( new wxBitmapDataObject(*(specplot->GetBitmap())));
    wxTheClipboard->Close();
  }
#endif
}
