/********************************************************************
  BasicDSP
  Copyright 2006-2007 
  Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org
  Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl
  License: GPLv2
********************************************************************/

#ifndef _graphframe_h
#define _graphframe_h

#include <vector>
#include "wx/wx.h"

#include "spectrumplot.h" 

class MyGraphFrame; //pre-declaration


/** The baseclass for an object that is called when a MyGraphFrame closes */ 
class GraphFrameCloseReceiver
{
public:
  virtual void GFrameCloseNotify(MyGraphFrame *isClosing) = 0;
};


/** MyGraphFrame a window that holds a plotting surface. */
class MyGraphFrame : public wxFrame
{
public:
  /** MyGraphFrame constructor
    param parent a pointer to the parent frame
    param title the title to be put on the window
    param checkboxnames an array containing names of the checkboxes that appear at the bottom of the dialog
    param xf dunno, not a very clear name
    param xfk at least 10^3 bigger than xf, I guess.
    param closereceiver, a pointer to a GraphFrameCloseReceiver object that will receive a notification when this window is closed. It can be NULL if no notification is required.
  */
	MyGraphFrame(wxFrame *parent, wxString title, wxArrayString checkboxnames, const wxString &xf, const wxString &xfk, GraphFrameCloseReceiver *closereceiver = NULL);
	virtual ~MyGraphFrame();

  /** Set the minimum and maximum Y-axis in dBs or linear modes and the X-axis zoom level 
    param dbmi minimum of Y-axis in dB mode
    param dbma maximum of Y-axis in dB mode
    param fmi minimum of Y-axis in linear mode 
    param fma maximum of Y-axis in linear mode
    param xz zoom of x-axis
  */
	void SetMinMax(float dbmi, float dbma, float fmi, float fma, float xz=1.0);

  /** Set the points of the display, a display refresh is done. 
    param l a pointer to an array of 1024 floats containing y data (1st trace).
    param r a pointer to an array of 1024 floats containing y data (2nd trace).
  */
	void SetLevel(float *l , float *r);

	bool check(int i) const { return checkboxes[i]->IsChecked(); };  // returns true if i'th checkbox has been selected
	wxString var_l() const { return varname_l->GetValue(); };        // returns variable name for 'left' channel
	wxString var_r() const { return varname_r->GetValue(); };        // returns variable name for 'right' channel

  /** Set the tooltip text for the checkbox with index 'boxnumber'. */
  void SetTooltip(int boxnumber, const wxString &tiptext);

	void OnClose(wxCloseEvent& event);
  void OnCopyToClipboard(wxCommandEvent& event);

	DECLARE_EVENT_TABLE()

private:
	wxFrame *myparent;
	wxSpectrumplot *specplot;
	std::vector<wxCheckBox*> checkboxes;
	wxTextCtrl *varname_l;
	wxTextCtrl *varname_r;
	GraphFrameCloseReceiver *closereceiver;

  wxButton  *toclipboard;
};

#endif
